==> basex_8.2.3.orig.tar.gz: basex-8.2.3/basex-core/src/main/java/org/basex/query/util/fingertree/EmptyTree.java <==
package org.basex.query.util.fingertree;

import java.util.*;

/**
 * An empty finger tree.
 *
 * @author BaseX Team 2005-15, BSD License
 * @author Leo Woerteler
 *
 * @param <N> node type
 * @param <E> element type
 */
final class EmptyTree<N, E> extends FingerTree<N, E> {
  /** The empty finger tree. */
  static final EmptyTree<?, ?> INSTANCE = new EmptyTree<>();

  /**
   * Getter for the empty finger tree.
   * @param <N> node type
   * @param <E> element type
   * @return empty tree
   */
  @SuppressWarnings("unchecked")
  static <N, E> EmptyTree<N, E> getInstance() {
    return (EmptyTree<N, E>) INSTANCE;
  }

  /** Hidden constructor. */
  private EmptyTree() {
  }

  @Override
  public FingerTree<N, E> cons(final Node<N, E> fst) {
    return new SingletonTree<>(fst);
  }

  @Override
  public FingerTree<N, E> snoc(final Node<N, E> lst) {
    return new SingletonTree<>(lst);
  }

  @Override
  public Node<N, E> head() {
    throw new NoSuchElementException();
  }

  @Override
  public Node<N, E> last() {
    throw new NoSuchElementException();
  }

  @Override
  public FingerTree<N, E> init() {
    throw new IllegalStateException("Empty Tree");
  }

  @Override
  public FingerTree<N, E> tail() {
    throw new IllegalStateException("Empty Tree");
  }

  @Override
  public long size() {
    return 0;
  }

  @Override
  public FingerTree<N, E> concat(final Node<N, E>[] nodes, final long sz,
      final FingerTree<N, E> other) {
    return other.addAll(nodes, sz, true);
  }

  @Override
  public TreeSlice<N, E> slice(final long pos, final long len) {
    if(pos == 0 && len == 0) return new TreeSlice<>(this);
    throw new AssertionError("Empty sub-tree.");
  }

  @Override
  public FingerTree<N, E> reverse() {
    return this;
  }

  @Override
  public FingerTree<N, E> insert(final long pos, final E val) {
    throw new AssertionError("Empty sub-tree.");
  }

  @Override
  public TreeSlice<N, E> remove(final long pos) {
    throw new AssertionError("Empty sub-tree.");
  }

  @Override
  public FingerTree<N, E> replaceHead(final Node<N, E> head) {
    throw new AssertionError("Empty sub-tree.");
  }

  @Override
  public FingerTree<N, E> replaceLast(final Node<N, E> last) {
    throw new AssertionError("Empty sub-tree.");
  }

  @Override
  void toString(final StringBuilder sb, final int indent) {
    for(int i = 0; i < indent; i++) sb.append("  ");
    sb.append("Empty[]");
  }

  @Override
  public long checkInvariants() {
    return 0;
  }

  @Override
  FingerTree<N, E> addAll(final Node<N, E>[] nodes, final long sz, final boolean left) {
    return buildTree(nodes, nodes.length, sz);
  }
}

==> basex_8.5.1.orig.tar.gz: basex-8.5.1/basex-core/src/main/java/org/basex/query/util/fingertree/EmptyTree.java <==
package org.basex.query.util.fingertree;

import java.util.*;

/**
 * An empty finger tree.
 *
 * @author BaseX Team 2005-16, BSD License
 * @author Leo Woerteler
 *
 * @param <N> node type
 * @param <E> element type
 */
final class EmptyTree<N, E> extends FingerTree<N, E> {
  /** The empty finger tree. */
  static final EmptyTree<?, ?> INSTANCE = new EmptyTree<>();

  /**
   * Getter for the empty finger tree.
   * @param <N> node type
   * @param <E> element type
   * @return empty tree
   */
  @SuppressWarnings("unchecked")
  static <N, E> EmptyTree<N, E> getInstance() {
    return (EmptyTree<N, E>) INSTANCE;
  }

  /** Hidden constructor. */
  private EmptyTree() {
  }

  @Override
  public FingerTree<N, E> cons(final Node<N, E> fst) {
    return new SingletonTree<>(fst);
  }

  @Override
  public FingerTree<N, E> snoc(final Node<N, E> lst) {
    return new SingletonTree<>(lst);
  }

  @Override
  public Node<N, E> head() {
    throw new NoSuchElementException();
  }

  @Override
  public Node<N, E> last() {
    throw new NoSuchElementException();
  }

  @Override
  public FingerTree<N, E> init() {
    throw new IllegalStateException("Empty Tree");
  }

  @Override
  public FingerTree<N, E> tail() {
    throw new IllegalStateException("Empty Tree");
  }

  @Override
  public FingerTree<N, E> set(final long pos, final E val) {
    throw new IndexOutOfBoundsException("Empty Tree");
  }

  @Override
  public long size() {
    return 0;
  }

  @Override
  public FingerTree<N, E> concat(final Node<N, E>[] nodes, final long sz,
      final FingerTree<N, E> other) {
    return other.addAll(nodes, sz, true);
  }

  @Override
  public TreeSlice<N, E> slice(final long pos, final long len) {
    if(pos == 0 && len == 0) return new TreeSlice<>(this);
    throw new AssertionError("Empty sub-tree.");
  }

  @Override
  public FingerTree<N, E> reverse() {
    return this;
  }

  @Override
  public FingerTree<N, E> insert(final long pos, final E val) {
    throw new AssertionError("Empty sub-tree.");
  }

  @Override
  public TreeSlice<N, E> remove(final long pos) {
    throw new AssertionError("Empty sub-tree.");
  }

  @Override
  public FingerTree<N, E> replaceHead(final Node<N, E> head) {
    throw new AssertionError("Empty sub-tree.");
  }

  @Override
  public FingerTree<N, E> replaceLast(final Node<N, E> last) {
    throw new AssertionError("Empty sub-tree.");
  }

  @Override
  void toString(final StringBuilder sb, final int indent) {
    for(int i = 0; i < indent; i++) sb.append("  ");
    sb.append("Empty[]");
  }

  @Override
  public long checkInvariants() {
    return 0;
  }

  @Override
  FingerTree<N, E> addAll(final Node<N, E>[] nodes, final long sz, final boolean left) {
    return buildTree(nodes, nodes.length, sz);
  }
}
